@@ -5,7 +5,7 @@ package IPC::PrettyPipe::Types;
 use strict;
 use warnings;
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 use Type::Library
   -base,
@@ -26,8 +26,8 @@ coerce AutoArrayRef,
   from Any, via { [$_] };
 
 class_type Pipe, { class => 'IPC::PrettyPipe' };
-class_type Cmd, { class => 'IPC::PrettyPipe::Cmd' };
-class_type Arg, { class => 'IPC::PrettyPipe::Arg' };
+class_type Cmd,  { class => 'IPC::PrettyPipe::Cmd' };
+class_type Arg,  { class => 'IPC::PrettyPipe::Arg' };
 
 
 1;
@@ -54,23 +54,23 @@ IPC::PrettyPipe::Types - Types
 
 =head1 VERSION
 
-version 0.12
+version 0.13
 
-=head1 BUGS
+=head1 SUPPORT
 
-Please report any bugs or feature requests on the bugtracker website
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=IPC-PrettyPipe> or by
-email to
-L<bug-IPC-PrettyPipe@rt.cpan.org|mailto:bug-IPC-PrettyPipe@rt.cpan.org>.
+=head2 Bugs
 
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
+Please report any bugs or feature requests to bug-ipc-prettypipe@rt.cpan.org  or through the web interface at: https://rt.cpan.org/Public/Dist/Display.html?Name=IPC-PrettyPipe
 
-=head1 SOURCE
+=head2 Source
 
-The development version is on github at L<https://github.com/djerius/ipc-prettypipe>
-and may be cloned from L<git://github.com/djerius/ipc-prettypipe.git>
+Source is available at
+
+  https://gitlab.com/djerius/ipc-prettypipe
+
+and may be cloned from
+
+  https://gitlab.com/djerius/ipc-prettypipe.git
 
 =head1 SEE ALSO
 
